.gitignore
Copyright.txt
LICENSE.txt
PEAR.php
README.md
Release_Notes.html
SPL-1.1.2.txt
SendSupportNotification.php
cache
composer.json
composer.lock
config.db.php
config.inc.php
config.performance.php
config.php
config.security.php
config.template.php
config_override.dev.php
config_override.sample.php
copyright.html
cron
data
favicon.ico
forgotPassword.php
htaccess.txt
include
includes
index.php
kcfinder
languages
layouts
libraries
license
log4php.properties
logs
migrate
modules
oauth2callback
packages
parent_tabdata.php
phpversionfail.php
pkg
public.php
resources
robots.txt
schema
shorturl.php
storage
tabdata.php
test
user_privileges
vendor
vtigercron.php
vtigerversion.php
vtlib
webservice.php
config.csrf-secret.php